@@ -14,12 +14,10 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
-from __future__ import absolute_import
-from calculate.consolegui import qt
+from .. import qt
 from .more import LabelWordWrap, _print, get_system_rgb, ParameterWindow, dpivalue
 
-DEBUG_LEVEL = 0
+DEBUG_LEVEL = 99999
 
 
 def debug(level, *args):
@@ -38,6 +36,8 @@ class MethodNameWgt(qt.QWidget):
         # Set style
         self.setAttribute(qt.Qt.WA_StyledBackground)
         self.setObjectName('ControlButton')
+        # self.setStyleSheet("QWidget#ControlButton "
+        #                    "{background-color: rgb(255,0,0);}")
         self.setStyleSheet("QWidget#ControlButton "
                            "{background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,"
                            "stop: 0 #111111, stop: 0.95 #777777, stop: 1 #666666);}")
@@ -147,6 +147,7 @@ class ControlButtonWgt(qt.QWidget):
 
     def set_confirm_question(self, message):
         self.question_label.setText(message)
+        debug(11, "set_confirm_question")
         self.question_label.show()
 
     def set_confirmation(self, wgt):
@@ -205,6 +206,11 @@ class ControlButtonWgt(qt.QWidget):
                 # button.setText(field.label.decode('utf-8'))
                 button.setText(field.label)
                 button.clicked.connect(self.button_disabled)
+                #DEBUG
+                # def f(*args, **kwargs):
+                #     print(f"Click on {field.label}")
+                #     return callback(*args, **kwargs)
+
                 button.clicked.connect(callback)
                 button.setMinimumWidth(62)
                 button.setFixedHeight(dpivalue(32))
