@@ -14,11 +14,9 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
-from __future__ import absolute_import
-from calculate.consolegui import qt
+from .. import qt
 
-DEBUG_LEVEL = 0
+DEBUG_LEVEL = 99999
 
 def debug(level, *args):
     if level <= DEBUG_LEVEL:
@@ -142,7 +140,7 @@ class MainFrameRes(qt.QWidget):
         self.updateGeometry()
 
     def show_bottom(self):
-        debug(20, "SHOW BOTTOM PAGE")
+        # debug(20, "SHOW BOTTOM PAGE")
         max_val = self._parent.main_frame.verticalScrollBar().maximum()
         current_val = \
             self._parent.main_frame.verticalScrollBar().sliderPosition()
@@ -986,6 +984,7 @@ class MainFrameRes(qt.QWidget):
     def send_Message(self, sid, pid, item):
         """ send answer to the question """
         self.message = MessageDialog(self, item, sid, pid)
+        debug(11, f"send message{item}")
         self.message.show()
 
     def send_Password(self, sid, pid, item):
@@ -1134,8 +1133,7 @@ class ButtonDialog(qt.QWidget):
         button = qt.QPushButton(label, self)
         if type(shortcut) in (list, tuple):
             action = qt.QAction(self)
-            action.setShortcuts(map(qt.QKeySequence,
-                                    shortcut))
+            action.setShortcuts([qt.QKeySequence(x) for x in shortcut])
             action.triggered.connect(button.animateClick)
             button.addAction(action)
         elif shortcut:
