@@ -14,18 +14,16 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
-from calculate.consolegui import qt
+from .. import qt
 import urllib.request as u2
 if hasattr(u2,"ssl"):
     u2.ssl._create_default_https_context = u2.ssl._create_unverified_context
 import os, re, sys
 
-
 import calculate.contrib
 from suds.transport.http import HttpTransport
 
-# try:
+
 from .pyopenssl_wrapper import PyOpenSSLSocket
 import http.client as httplib
 from suds.transport import Transport
@@ -612,17 +610,17 @@ class CheckingClientHTTPSConnection(httplib.HTTPSConnection):
                 return 0
             
             except OpenSSL.SSL.Error as e:
-                if type(e.message) == list:
-                    if type(e.message[0]) == tuple:
-                        for i in e.message[0]:
+                if type(e) == list:
+                    if type(e[0]) == tuple:
+                        for i in e[0]:
                             sys.stdout.write(i+' ')
                             sys.stdout.flush()
                         sys.stdout.write('\n')
                         sys.stdout.flush()
                     else:
-                        _print (e.message)
+                        _print (e)
                 else:
-                    _print (e.message)
+                    _print (e)
                 HTTPSClientCertTransport.filename = None
                 return 1
 
