@@ -14,8 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
-from calculate.consolegui import qt
+from .. import qt
 import calculate.contrib
 from suds import WebFault
 import logging, OpenSSL
@@ -350,7 +349,7 @@ class FrameConnection(qt.QWidget):
                     Connect_Error = 0
                 except VerifyError as e:
                     show_msg (e.value,_("Server certificate verification error"),self)
-                    e.message = 'VerifyError'
+                    e = 'VerifyError'
                     Connect_Error = 1
                 except OpenSSL.crypto.Error as e:
                     print("OPENSSL ERROR")
@@ -380,9 +379,9 @@ class FrameConnection(qt.QWidget):
                             _("Also you can generate administrator certificate by root command"),
                             getpass.getuser())
                     show_msg (mess, parent = self)
-                elif e.message == 'VerifyError':
+                elif e == 'VerifyError':
                     pass
-                elif e.message == 1:
+                elif e == 1:
                     mess = _('You do not have a certificate or your '
                           'certificate does not match the server certificate.'
                           ' Please generate a new request and get the new '
@@ -393,7 +392,7 @@ class FrameConnection(qt.QWidget):
                             getpass.getuser())
                     show_msg (mess, parent = self)
                 else:
-                    if e.message or e.args:
+                    if e or e.args:
                         show_msg (e, parent = self)
                 return
                 CERT_FILE = None
